Learn R Programming

boostingDEA (version 0.1.0)

EstimCoeffsForward: Estimate Coefficients in Multivariate Adaptive Frontier Splines during Forward Procedure.

Description

This function solves a Quadratic Programming Problem to obtain a set of coefficients.

Usage

EstimCoeffsForward(B, y)

Value

vector with the coefficients estimated.

Arguments

B

matrix of basis functions.

y

Output vector in data.