Learn R Programming

boostingDEA (version 0.1.0)

banks: Taiwanese banks (in 2010)

Description

The dataset consists of 31 banks operating in Taiwan.

Usage

data(banks)

Arguments

Format

banks is a dataframe with 31 banks (rows) and 6 variables (outputs) named Financial.funds (deposits and borrowed funds in millions of TWD), Labor (number of employees), Physical.capital (net amount of fixed assets in millions of TWD), Finalcial.investments (financial assets, securities, and equity investments in millions of TWD), Loans (loans and discounts in millions of TWD) and Revenue (interests from financial investments and loans).

References

Juo, J. C., Fu, T. T., Yu, M. M., & Lin, Y. H. (2015). Profit-oriented productivity change. Omega, 57, 176-187.