Learn R Programming

boostingDEA (version 0.1.0)

bestEATBoost: Tuning an EATBoost model

Description

This function computes the root mean squared error (RMSE) for a set of EATBoost models built with a grid of given hyperparameters.

Usage

bestEATBoost(
  training,
  test,
  x,
  y,
  num.iterations,
  learning.rate,
  num.leaves,
  verbose = TRUE
)

Value

A data.frame with the sets of hyperparameters and the root mean squared error (RMSE) and mean square error (MSE) associated for each model.

Arguments

training

Training data.frame or matrix containing the variables for model construction.

test

Test data.frame or matrix containing the variables for model assessment.

x

Column input indexes in training.

y

Column output indexes in training.

num.iterations

Maximum number of iterations the algorithm will perform

learning.rate

Learning rate that control overfitting of the algorithm. Value must be in (0,1]

num.leaves

Maximum number of terminal leaves in each tree at each iteration

verbose

Controls the verbosity.