Learn R Programming

boostingDEA (version 0.1.0)

bestMARSBoost: Tuning an MARSBoost model

Description

This funcion computes the root mean squared error (RMSE) for a set of MARSBoost models built with a grid of given hyperparameters.

Usage

bestMARSBoost(
  training,
  test,
  x,
  y,
  num.iterations,
  learning.rate,
  num.terms,
  verbose = TRUE
)

Value

A data.frame with the sets of hyperparameters and the root mean squared error (RMSE) associated for each model.

Arguments

training

Training data.frame or matrix containing the variables for model construction.

test

Test data.frame or matrix containing the variables for model assessment.

x

Column input indexes in training.

y

Column output indexes in training.

num.iterations

Maximum number of iterations the algorithm will perform

learning.rate

Learning rate that control overfitting of the algorithm. Value must be in (0,1]

num.terms

Maximum number of reflected pairs created by the forward algorithm of MARS.

verbose

Controls the verbosity.