EATBoostCalculates the inferior corner of the support of all leave nodes
of every tree created in the EATBoost model
get.a.trees(EATBoost_model)list of matrix. The length of the list is equal to
the num.iterations of the EATBoost_model. Each matrix
corresponds to a tree, where the number of columns is the number of input variables and the number of rows to the number of leaves
Model from class EATBoost from which the data
are obtained