Learn R Programming

boostingDEA (version 0.1.0)

mse_tree: Mean Squared Error

Description

This function calculates the Mean Square Error between the predicted value and the observations in a given node.

Usage

mse_tree(data, t, y)

Value

Mean Square Error at a node.

Arguments

data

Data to be used.

t

A given node.

y

Column output indexes in data.