This function computes the root mean squared error (RMSE) for a set of EATBoost models built with a grid of given hyperparameters.
bestEATBoost(
training,
test,
x,
y,
num.iterations,
learning.rate,
num.leaves,
verbose = TRUE
)A data.frame with the sets of hyperparameters and the root
mean squared error (RMSE) and mean square error (MSE) associated for each
model.
Training data.frame or matrix containing the
variables for model construction.
Test data.frame or matrix containing the variables
for model assessment.
Column input indexes in training.
Column output indexes in training.
Maximum number of iterations the algorithm will perform
Learning rate that control overfitting of the algorithm. Value must be in (0,1]
Maximum number of terminal leaves in each tree at each iteration
Controls the verbosity.