This funcion computes the root mean squared error (RMSE) for a set of MARSBoost models built with a grid of given hyperparameters.
bestMARSBoost(
training,
test,
x,
y,
num.iterations,
learning.rate,
num.terms,
verbose = TRUE
)A data.frame with the sets of hyperparameters and the root
mean squared error (RMSE) associated for each model.
Training data.frame or matrix containing the
variables for model construction.
Test data.frame or matrix containing the variables
for model assessment.
Column input indexes in training.
Column output indexes in training.
Maximum number of iterations the algorithm will perform
Learning rate that control overfitting of the algorithm. Value must be in (0,1]
Maximum number of reflected pairs created by the forward algorithm of MARS.
Controls the verbosity.